.. _recipe_asr.plasmafrequency:

asr.plasmafrequency
===================


.. contents:: Contents
   :local:

Summary
-------

This is the documentation for :py:mod:`asr.plasmafrequency`-recipe.
This recipe is comprised of 2 steps, namely:

  - :py:func:`asr.plasmafrequency.calculate`
  - :py:func:`asr.plasmafrequency.main`

Run this recipe through the CLI interface

.. code-block:: console

   $ asr run asr.plasmafrequency

or as a python module

.. code-block:: console

   $ python -m asr.plasmafrequency

Detailed description
--------------------
Plasma frequency.

Steps
-----


asr.plasmafrequency@calculate
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
.. autofunction:: asr.plasmafrequency.calculate
   

asr.plasmafrequency
^^^^^^^^^^^^^^^^^^^
.. autofunction:: asr.plasmafrequency.main
   